@@ -3,9 +3,8 @@
 LCSdist <- function(seq1,l1,seq2,l2,norm) {
 
 	result <- .C("cLCS", as.integer(seq1), as.integer(seq2), as.double(c(l1,l2)), result = as.integer(0), PACKAGE="TraMineR")$result
-	
-	if (norm==FALSE) dist <- l1+l2-2*(result)
-	else dist <- 1-(result/sqrt(l1*l2))
+	dist <- l1+l2-2*result
+  return(normdist(dist,l1+l2, l1,l2,norm))
 
 	return(dist)
 }
